from distutils.core import setup

setup(
    name='shangyi',
    version='1.0.0',
    py_modules=['nester'],
    author='shangyipythom',
    author_email='shangyix@163.com',
    url='https://blog.csdn.net/tw18761720160/article/details/52826450',
    description='A new pythoner',
    )
